@@ -12,7 +12,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Alternatives::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Alternatives::VERSION    = '2.002001';
+	$Type::Params::Alternatives::VERSION    = '2.006000';
 }
 
 $Type::Params::Alternatives::VERSION =~ tr/_//d;
@@ -97,7 +97,6 @@ sub _coderef_start_extra {
 	my ( $self, $coderef ) = ( shift, @_ );
 	
 	$coderef->add_line( 'my $r;' );
-	$coderef->add_line( 'undef ${^TYPE_PARAMS_MULTISIG};' );
 	$coderef->add_line( 'undef ${^_TYPE_PARAMS_MULTISIG};' );
 	$coderef->add_gap;
 
@@ -127,7 +126,7 @@ sub _coderef_meta_alternative {
 		my $alt_code = $meta->{source};
 		$alt_code =~ s/^sub [{]/do {/;
 		$coderef->add_line( sprintf(
-			'eval { local @_ = @_; $r = [ %s ]; ${^TYPE_PARAMS_MULTISIG} = ${^_TYPE_PARAMS_MULTISIG} = %d }%sif ( %s );',
+			'eval { local @_ = @_; $r = [ %s ]; ${^_TYPE_PARAMS_MULTISIG} = %d }%sif ( %s );',
 			$alt_code,
 			$meta->{_index},
 			"\n\t",
@@ -139,7 +138,7 @@ sub _coderef_meta_alternative {
 		
 		my $callback_var = $coderef->add_variable( '$signature', \$meta->{closure} );
 		$coderef->add_line( sprintf(
-			'eval { $r = [ %s->(@_) ]; ${^TYPE_PARAMS_MULTISIG} = ${^_TYPE_PARAMS_MULTISIG} = %d }%sif ( %s );',
+			'eval { $r = [ %s->(@_) ]; ${^_TYPE_PARAMS_MULTISIG} = %d }%sif ( %s );',
 			$callback_var,
 			$meta->{_index},
 			"\n\t",
