@@ -11,7 +11,7 @@ use Scalar::Util ();
 {
 	package Type::Tie;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '2.002001';
+	our $VERSION   = '2.006000';
 	our @ISA       = qw( Exporter::Tiny );
 	our @EXPORT    = qw( ttie );
 	
@@ -22,16 +22,13 @@ use Scalar::Util ();
 		my ( $ref, $type, @vals ) = @_;
 		
 		if ( 'HASH' eq ref $ref ) {
-			tie %$ref, "Type::Tie::HASH", $type;
-			%$ref = @vals if @vals;
+			tie %$ref, "Type::Tie::HASH", $type, @vals;
 		}
 		elsif ( 'ARRAY' eq ref $ref ) {
-			tie @$ref, "Type::Tie::ARRAY", $type;
-			@$ref = @vals if @vals;
+			tie @$ref, "Type::Tie::ARRAY", $type, @vals;
 		}
 		else {
-			tie $$ref, "Type::Tie::SCALAR", $type;
-			$$ref = $vals[-1] if @vals;
+			tie $$ref, "Type::Tie::SCALAR", $type, @vals;
 		}
 		return $ref;
 	}
@@ -40,7 +37,7 @@ use Scalar::Util ();
 {
 	package Type::Tie::BASE;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '2.002001';
+	our $VERSION   = '2.006000';
 	
 	$VERSION =~ tr/_//d;
 	
@@ -164,15 +161,20 @@ use Scalar::Util ();
 {
 	package Type::Tie::ARRAY;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '2.002001';
+	our $VERSION   = '2.006000';
 	our @ISA       = qw( Type::Tie::BASE );
 	
 	$VERSION =~ tr/_//d;
 	
 	sub TIEARRAY   {
 		my $class = shift;
+		my $type  = shift;
 		my $self  = bless( [ $class->_DEFAULT ], $class );
-		$self->_set_type( $_[0] );
+		$self->_set_type( $type );
+		if ( @_ ) {
+			my $R = $self->_REF;
+			@$R = map { $self->coerce_and_check_value( $_ ) } @_;
+		}
 		$self;
 	}
 	sub _DEFAULT   { [] }
@@ -202,15 +204,24 @@ use Scalar::Util ();
 {
 	package Type::Tie::HASH;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '2.002001';
+	our $VERSION   = '2.006000';
 	our @ISA       = qw( Type::Tie::BASE );
 	
 	$VERSION =~ tr/_//d;
 	
 	sub TIEHASH    {
 		my $class = shift;
+		my $type  = shift;
 		my $self  = bless( [ $class->_DEFAULT ], $class );
-		$self->_set_type( $_[0] );
+		$self->_set_type( $type );
+		if ( @_ ) {
+			my $R = $self->_REF;
+			my %H = @_;
+			%$R = ();
+			while ( my ( $K, $V ) = each %H ) {
+				$R->{$K} = $self->coerce_and_check_value( $V );
+			}
+		}
 		$self;
 	}
 	sub _DEFAULT   { +{} }
@@ -228,15 +239,23 @@ use Scalar::Util ();
 {
 	package Type::Tie::SCALAR;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '2.002001';
+	our $VERSION   = '2.006000';
 	our @ISA       = qw( Type::Tie::BASE );
 	
 	$VERSION =~ tr/_//d;
 	
 	sub TIESCALAR  {
 		my $class = shift;
+		my $type  = shift;
 		my $self  = bless( [ $class->_DEFAULT ], $class );
-		$self->_set_type($_[0]);
+		$self->_set_type($type);
+		if ( @_ ) {
+			Carp::croak( 'Too many initial values provided for SCALAR' ) if @_ > 1;
+			${ $self->_REF } = $self->coerce_and_check_value( $_[0] );
+		}
+		elsif ( $type->can('type_default') and my $d = $type->type_default ) {
+			${ $self->_REF } = $d->();
+		}
 		$self;
 	}
 	sub _DEFAULT   { my $x; \$x }
@@ -381,7 +400,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2018-2019, 2022-2023 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2018-2019, 2022-2024 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
