@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION    = '2.002001';
+	$Type::Tiny::VERSION    = '2.006000';
 	$Type::Tiny::XS_VERSION = '0.016';
 }
 
@@ -86,7 +86,7 @@ sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 sub _swap { $_[2] ? @_[ 1, 0 ] : @_[ 0, 1 ] }
 
 BEGIN {
-	my $support_smartmatch = 0+ !!( $] >= 5.010001 );
+	my $support_smartmatch = 0+ !!( $] >= 5.010001 && $] <= 5.041002 );
 	eval qq{ sub SUPPORT_SMARTMATCH () { !! $support_smartmatch } };
 	
 	my $fixed_precedence = 0+ !!( $] >= 5.014 );
@@ -534,6 +534,7 @@ sub mouse_type           { $_[0]{mouse_type} ||= $_[0]->_build_mouse_type }
 sub deep_explanation     { $_[0]{deep_explanation} }
 sub my_methods           { $_[0]{my_methods} ||= $_[0]->_build_my_methods }
 sub sorter               { $_[0]{sorter} }
+sub exception_class      { $_[0]{exception_class} ||= $_[0]->_build_exception_class }
 
 sub has_parent               { exists $_[0]{parent} }
 sub has_library              { exists $_[0]{library} }
@@ -636,6 +637,13 @@ sub _build_compiled_check {
 	};
 } #/ sub _build_compiled_check
 
+sub _build_exception_class {
+	my $self = shift;
+	return $self->parent->exception_class if $self->has_parent;
+	require Error::TypeTiny::Assertion;
+	return 'Error::TypeTiny::Assertion';
+}
+
 sub definition_context {
 	my $self  = shift;
 	my $found = $self->find_parent(sub {
@@ -1002,6 +1010,8 @@ sub inline_assert {
 	my $self = shift;
 	my ( $varname, $typevarname, %extras ) = @_;
 	
+	$extras{exception_class} ||= $self->exception_class;
+	
 	my $inline_check;
 	if ( $self->can_be_inlined ) {
 		$inline_check = sprintf( '(%s)', $self->inline_check( $varname ) );
@@ -1047,13 +1057,11 @@ sub inline_assert {
 } #/ sub inline_assert
 
 sub _failed_check {
-	require Error::TypeTiny::Assertion;
-	
 	my ( $self, $name, $value, %attrs ) = @_;
 	$self = $ALL_TYPES{$self} if defined $self && !ref $self;
 	
-	my $exception_class =
-		delete( $attrs{exception_class} ) || "Error::TypeTiny::Assertion";
+	my $exception_class = delete( $attrs{exception_class} )
+		|| ( ref $self ? $self->exception_class : 'Error::TypeTiny::Assertion' );
 	my $callback = delete( $attrs{on_die} );
 
 	if ( $self ) {
@@ -1928,6 +1936,12 @@ You may pass C<< coercion => 1 >> to the constructor to inherit coercions
 from the constraint's parent. (This requires the parent constraint to have
 a coercion.)
 
+If an arrayref is passed to the constructor (C<< coercion => [ ... ] >>),
+then the coercion object will be lazily built and this array will be fed to
+its C<add_type_coercions> method. If a coderef is passed to the constructor
+(C<< coercion => sub { ... } >>), then the coercion object will be lazily built
+and this code will be used as a coercion from B<Any>.
+
 =item C<< sorter >>
 
 A coderef which can be passed two values conforming to this type constraint
@@ -1984,6 +1998,16 @@ for the reader.
 Experimental hashref of additional methods that can be called on the type
 constraint object.
 
+=item C<< exception_class >>
+
+The class used to throw an exception when a value fails its type check.
+Defaults to "Error::TypeTiny::Assertion", which is usually good. This class
+is expected to provide a C<throw_cb> method compatible with the method of
+that name in L<Error::TypeTiny>.
+
+If a parent type constraint has a custom C<exception_class>, then this
+will be "inherited" by its children.
+
 =back
 
 =head3 Attributes related to parameterizable and parameterized types
@@ -2727,7 +2751,7 @@ Thanks to Matt S Trout for advice on L<Moo> integration.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2023 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2024 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
